package com.yanzhu.jh.work.service;

import java.util.List;
import java.util.Map;

import com.yanzhu.jh.work.domain.WorkFileUser;

/**
 * 文件访问用户Service接口
 * 
 * @author JiangYuQi
 * @date 2023-10-22
 */
public interface IWorkFileUserService 
{
    /**
     * 查询文件访问用户
     * 
     * @param id 文件访问用户主键
     * @return 文件访问用户
     */
    public WorkFileUser selectWorkFileUserById(Long id);

    /**
     * 查询文件访问用户列表
     * 
     * @param workFileUser 文件访问用户
     * @return 文件访问用户集合
     */
    public List<WorkFileUser> selectWorkFileUserList(WorkFileUser workFileUser);

    /**
     * 统计文件访问用户列表
     *
     * @param workFileUser 文件访问用户
     * @return 文件访问用户集合
     */
    public List<Map<String,Object>> queryCountByDeptType(WorkFileUser workFileUser);

    /**
     * 新增文件访问用户
     * 
     * @param workFileUser 文件访问用户
     * @return 结果
     */
    public int insertWorkFileUser(WorkFileUser workFileUser);

    /**
     * 修改文件访问用户
     * 
     * @param workFileUser 文件访问用户
     * @return 结果
     */
    public int updateWorkFileUser(WorkFileUser workFileUser);

    /**
     * 批量删除文件访问用户
     * 
     * @param ids 需要删除的文件访问用户主键集合
     * @return 结果
     */
    public int deleteWorkFileUserByIds(Long[] ids);

    /**
     * 删除文件访问用户信息
     * 
     * @param id 文件访问用户主键
     * @return 结果
     */
    public int deleteWorkFileUserById(Long id);
}
